@@ -19,14 +19,17 @@ our @EXPORT_OK = qw(
     copy_changes
     copy_makefile
     copy_module_files
-    copy_manifest_skip
+    copy_manifest
     copy_git_ignore
 
+    cpan_save
+    cpan_restore
+
     unlink_changes
     unlink_ci_files
     unlink_makefile
     unlink_module_files
-    unlink_manifest_skip
+    unlink_manifest
     unlink_git_ignore
 
     mkdir_init
@@ -47,7 +50,7 @@ our %EXPORT_TAGS = (all => \@EXPORT_OK);
 
 my $orig_dir        = 't/data/orig';
 my $work_dir        = 't/data/work';
-my $tpl_dir         = 't/data/module_template';
+my $tpl_dir         = 't/data/template/module_template';
 my $unwanted_dir    = 't/data/work/unwanted';
 my $init_dir        = 't/data/work/init';
 my $ci_dir          = 't/data/work/ci';
@@ -64,6 +67,9 @@ sub copy_changes {
     $y+= 1900;
     $m+= 1;
 
+    $d = "0$d" if length $d == 1;
+    $m = "0$m" if length $m == 1;
+
     my $changes_release = "$work_dir/Changes-release";
 
     my $tie = tie my @changes, 'Tie::File', $changes_release;
@@ -85,13 +91,29 @@ sub copy_module_files {
         copy $_, $work_dir or die $!;
     }
 }
-sub copy_manifest_skip {
+sub copy_manifest {
     copy "$orig_dir/MANIFEST.SKIP", $work_dir or die $!;
+    copy "$orig_dir/manifest.t", $work_dir or die $!;
 }
 sub copy_git_ignore {
     copy "$orig_dir/.gitignore", $work_dir or die $!;
 }
 
+sub cpan_save {
+    my $f = "$ENV{HOME}/dist-mgr.json";
+
+    if (-e $f) {
+        copy $f, "$f.bak" or die "Can't copy config file: $!";
+    }
+}
+sub cpan_restore {
+    my $f = "$ENV{HOME}/dist-mgr.json";
+
+    if (-e "$f.bak") {
+        copy "$f.bak", $f or die "Can't copy config file: $!";
+    }
+}
+
 sub unlink_changes {
     if (-e "$work_dir/Changes") {
         unlink "$work_dir/Changes" or die $!;
@@ -128,11 +150,16 @@ sub unlink_module_files {
         is -e $_, undef, "unlinked $_ file ok";
     }
 }
-sub unlink_manifest_skip {
+sub unlink_manifest {
     if (-e "$work_dir/MANIFEST.SKIP") {
         unlink "$work_dir/MANIFEST.SKIP" or die $!;
     }
     is -e "$work_dir/MANIFEST.SKIP", undef, "temp MANIFEST.SKIP deleted ok";
+
+    if (-e "$work_dir/manifest.t") {
+        unlink "$work_dir/manifest.t" or die $!;
+    }
+    is -e "$work_dir/manifest.t", undef, "temp manifest.t deleted ok";
 }
 sub unlink_git_ignore {
     if (-e "$work_dir/.gitignore") {
@@ -158,7 +185,11 @@ sub file_compare {
     close $orig_fh or die $!;
 
     for (0..$#new) {
-        is $new[$_], $orig[$_], "Updated Changes file line $_ matches template custom ok";
+        $new[$_] =~ s/[\r\n]//g;
+        $orig[$_] =~ s/[\r\n]//g;
+        chomp $orig;
+
+        like $new[$_], qr/^$orig[$_]/, "Updated Changes file line $_ matches template custom ok";
     }
 }
 sub file_scalar {
@@ -217,6 +248,17 @@ sub trap_warn {
     }
 }
 
+sub make_second_module {
+    my ($dest) = @_;
+
+    if (! -e $dest) {
+        mkdir $dest or die "Can't create $dest dir\n";
+        is -d $dest, 1, "$dest dir created ok";
+    }
+
+    copy 't/data/orig/One.pm', $dest or die "Can't copy One.pm to $dest\n";
+
+}
 sub module_args {
     my %module_args = (
         author  => 'Test Author',
@@ -265,4 +307,4 @@ sub verify_clean {
     is(scalar(find_module_files($work_dir)), 0, "all work module files unlinked ok");
 }
 
-1;
\ No newline at end of file
+1;
